<?xml version='1.0'?>
<xsl:stylesheet 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	version="1.0"
	>

<xsl:import href="/usr/share/xml/docbook/stylesheet/docbook-xsl/xhtml/docbook.xsl"/>
<xsl:import href="mytitlepage.xsl"/>

<xsl:output method="html" indent="yes" encoding="UTF-8"
		doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN"
		doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd"
		omit-xml-declaration="yes"
		/>

<!-- supress index -->
<xsl:template match="index"/>

<!--insert into <head> a <script> element containing the script in the -->
<!-- html-customization/javascript.xml file-->
<xsl:template name="user.head.content">
   <xsl:variable name="codefile" select="document('../../../html-customization/javascript.xml',/)"/>
   <xsl:copy-of select="$codefile/javascript/node()"/>
</xsl:template>


<!-- javascript getdivs function to run on body load -->
<xsl:template name="body.attributes">
  <xsl:attribute name="onLoad">getdivs();start();</xsl:attribute>
</xsl:template>

<!--Insert the button panel in the toc-->
<xsl:template name="make.toc">
  <xsl:param name="toc-context" select="."/>
  <xsl:param name="toc.title.p" select="true()"/>
  <xsl:param name="nodes" select="/NOT-AN-ELEMENT"/>

  <xsl:variable name="nodes.plus" select="$nodes | qandaset"/>

  <xsl:variable name="toc.title">
    <xsl:if test="$toc.title.p">
<!--doctemplate mod: -->
    <div xmlns="http://www.w3.org/1999/xhtml" class="buttonpanel">
    	<button onclick="showPrevious();">Previous</button><button onclick="showNext();">Next</button>
    </div>
<!--doctemplate end mod -->
      <p>
        <b>
          <xsl:call-template name="gentext">
            <xsl:with-param name="key">TableofContents</xsl:with-param>
          </xsl:call-template>
        </b>
      </p>
    </xsl:if>
  </xsl:variable>

  <xsl:choose>
    <xsl:when test="$manual.toc != ''">
      <xsl:variable name="id">
        <xsl:call-template name="object.id"/>
      </xsl:variable>
      <xsl:variable name="toc" select="document($manual.toc, .)"/>
      <xsl:variable name="tocentry" select="$toc//tocentry[@linkend=$id]"/>
      <xsl:if test="$tocentry and $tocentry/*">
        <div class="toc">
          <xsl:copy-of select="$toc.title"/>
          <xsl:element name="{$toc.list.type}" namespace="http://www.w3.org/1999/xhtml">
            <xsl:call-template name="manual-toc">
              <xsl:with-param name="tocentry" select="$tocentry/*[1]"/>
            </xsl:call-template>
          </xsl:element>
        </div>
      </xsl:if>
    </xsl:when>
    <xsl:otherwise>
      <xsl:choose>
        <xsl:when test="$qanda.in.toc != 0">
          <xsl:if test="$nodes.plus">
            <div class="toc">
              <xsl:copy-of select="$toc.title"/>
              <xsl:element name="{$toc.list.type}" namespace="http://www.w3.org/1999/xhtml">
                <xsl:apply-templates select="$nodes.plus" mode="toc">
                  <xsl:with-param name="toc-context" select="$toc-context"/>
                </xsl:apply-templates>
              </xsl:element>
            </div>
          </xsl:if>
        </xsl:when>
        <xsl:otherwise>
          <xsl:if test="$nodes">
            <div class="toc">
              <xsl:copy-of select="$toc.title"/>
              <xsl:element name="{$toc.list.type}" namespace="http://www.w3.org/1999/xhtml">
                <xsl:apply-templates select="$nodes" mode="toc">
                  <xsl:with-param name="toc-context" select="$toc-context"/>
                </xsl:apply-templates>
              </xsl:element>
            </div>
          </xsl:if>
        </xsl:otherwise>
      </xsl:choose>

    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template name="toc.line">
  <xsl:param name="toc-context" select="."/>
  <xsl:param name="depth" select="1"/>
  <xsl:param name="depth.from.context" select="8"/>

<!-- Suppress index in toc -->
	<xsl:choose>
		<xsl:when test="name() != 'index'">
<!-- doctemplate end mod: -->

		 <span>
		  <xsl:attribute name="class"><xsl:value-of select="local-name(.)"/></xsl:attribute>

		  <!-- * if $autotoc.label.in.hyperlink is zero, then output the label -->
		  <!-- * before the hyperlinked title (as the DSSSL stylesheet does) -->
		  <xsl:if test="$autotoc.label.in.hyperlink = 0">
			<xsl:variable name="label">
			  <xsl:apply-templates select="." mode="label.markup"/>
			</xsl:variable>
			<xsl:copy-of select="$label"/>
			<xsl:if test="$label != ''">
			  <xsl:value-of select="$autotoc.label.separator"/>
			</xsl:if>
		  </xsl:if>

		  <a>
<!-- dcoctemplate mod: add onclick="showdiv(<sect1>) for sect1s and sect2s -->
		  <xsl:variable name="toconclick">
			<xsl:choose>
				<xsl:when test="name() = 'sect1'">showdiv('#<xsl:value-of select="@id"/>');</xsl:when>
				<xsl:when test="name() = 'sect2'">showdiv('#<xsl:value-of select="../@id"/>');</xsl:when>
			</xsl:choose>
		  </xsl:variable>
			<xsl:attribute name="onClick"><xsl:copy-of select="$toconclick"/></xsl:attribute>
<!--doctemplate end mod -->

			<xsl:attribute name="href">
			  <xsl:call-template name="href.target">
				<xsl:with-param name="context" select="$toc-context"/>
				<xsl:with-param name="toc-context" select="$toc-context"/>
			  </xsl:call-template>
			</xsl:attribute>
		
		  <!-- * if $autotoc.label.in.hyperlink is non-zero, then output the label -->
		  <!-- * as part of the hyperlinked title -->
		  <xsl:if test="not($autotoc.label.in.hyperlink = 0)">
			<xsl:variable name="label">
			  <xsl:apply-templates select="." mode="label.markup"/>
			</xsl:variable>
			<xsl:copy-of select="$label"/>
			<xsl:if test="$label != ''">
			  <xsl:value-of select="$autotoc.label.separator"/>
			</xsl:if>
		  </xsl:if>

			<xsl:apply-templates select="." mode="titleabbrev.markup"/>
		  </a>
		  </span>
<!-- doctemplate mod: to suppress index in toc -->
		</xsl:when>
	</xsl:choose>
<!--doctemplate end mod -->
</xsl:template>

<!-- insert id attribute for sect1 so javascript can show the clicked toc div -->
<!-- based on non-localized value (the id, not the title -->
<xsl:template match="sect1">
  <xsl:call-template name="id.warning"/>

  <div>
  	<xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
    <xsl:call-template name="common.html.attributes">
      <xsl:with-param name="inherit" select="1"/>
    </xsl:call-template>

    <xsl:choose>
      <xsl:when test="@renderas = 'sect2'">
        <xsl:call-template name="sect2.titlepage"/>
      </xsl:when>
      <xsl:when test="@renderas = 'sect3'">
        <xsl:call-template name="sect3.titlepage"/>
      </xsl:when>
      <xsl:when test="@renderas = 'sect4'">
        <xsl:call-template name="sect4.titlepage"/>
      </xsl:when>
      <xsl:when test="@renderas = 'sect5'">
        <xsl:call-template name="sect5.titlepage"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:call-template name="sect1.titlepage"/>
      </xsl:otherwise>
    </xsl:choose>

    <xsl:variable name="toc.params">
      <xsl:call-template name="find.path.params">
        <xsl:with-param name="table" select="normalize-space($generate.toc)"/>
      </xsl:call-template>
    </xsl:variable>

    <xsl:if test="contains($toc.params, 'toc')                   and $generate.section.toc.level &gt;= 1">
      <xsl:call-template name="section.toc">
        <xsl:with-param name="toc.title.p" select="contains($toc.params, 'title')"/>
      </xsl:call-template>
      <xsl:call-template name="section.toc.separator"/>
    </xsl:if>
    <xsl:apply-templates/>
    <xsl:call-template name="process.chunk.footnotes"/>
  </div>
</xsl:template>


<!--Provide an attribute so css and do what it wants-->
<xsl:template match="programlisting">
	<pre xmlns="http://www.w3.org/1999/xhtml" class="programlisting">
		<xsl:apply-templates/>
	</pre>
</xsl:template>

<!--Because index is not currently supported in html, we need to display the indexterm-->
<!--text content and it doesn't matter that we may be overriding index mechanisms -->
<xsl:template match="indexterm">
	<xsl:value-of select="."/>
</xsl:template>

<xsl:template match="link">
	<a xmlns="http://www.w3.org/1999/xhtml">
		<xsl:attribute name="href"><xsl:value-of select="."/></xsl:attribute>
		<xsl:value-of select="."/>
	</a>
</xsl:template>

<xsl:template match="application">
	<span xmlns="http://www.w3.org/1999/xhtml" class="emphasis"><xsl:value-of select="."/></span>
</xsl:template>

</xsl:stylesheet>
